#############################################
# Econometrics SzDF                         #
# Creating dataset from OECD REPOSITORIES   #
#############################################

rm(list=ls())
source("libs.R")

#AVAILABLE DATASETS
OECD.datasets<-get_datasets()
# View(OECD.datasets)

#QUARTERLY NATIONAL ACCOUNTS DATASET STRUCTURE
QNA.structure <- get_data_structure("QNA")
str(QNA.structure,max.level=2)

#FETCH DATA
# View(QNA.structure$LOCATION)
# View(QNA.structure$SUBJECT)
# View(QNA.structure$MEASURE)

cntrList = c("AUS","AUT","BEL","CAN","DNK","FIN","FRA","DEU",
             "GRC","IRL","ITA","JPN","KOR","MEX","NLD","NZL","NOR",
             "PRT","ESP","SWE","CHE","GBR","USA","OECD")


QNA<-get_dataset("QNA",filter=list(LOCATION=cntrList,
                                   SUBJECT=c("B1_GE"),
                                   MEASURE=c("VPVOBARSA"),
                                   FREQUENCY=c("Q")))

# OUR DATASET -- LONGTABLE
head(QNA)

# WIDE FORMAT -- ZOO OBJECT

GDP<-QNA%>%
  dplyr::select(LOCATION,Time,ObsValue)%>%
  dplyr::mutate(ObsValue = as.numeric(ObsValue))%>%
  tidyr::spread(key=LOCATION,value=ObsValue)

dataGDP <- zoo(GDP[,-1],as.yearqtr(GDP$Time,format = "%Y-Q%q"))
dataGDP <- window(dataGDP, start=as.yearqtr("1975q1"))
  
cnt = c("DEU","USA")

#PLOT DATA
plot(100*diff(log(dataGDP[,cnt]),4),col=1:2,
     main=paste("GDP in ",cnt[1]," and ",cnt[2]," (% YoY)",sep=""), 
     type = "l", ylab="",xlab="", bty="l",plot.type="single",las=1)
legend("bottomleft",legend=cnt,col=1:2,lty=1, bty="n")


# writting to csv
save(dataGDP,file="dataGDP.Rdata")
write.csv(as.data.frame(dataGDP),file="dataGDP.csv")
