################################
# Econometrics SzD             #
# Topic 1: Linear Regression   #
################################
rm(list=ls())

# 1. Exercise 1.3
N = 50
x = rnorm(N,5,2)
epsilon = rnorm(N,0,1)
y = 5+0.5*x+epsilon

summary(lm(y~x))

# 2. OLS
filename <- "baseball.csv"
data     <- read.csv(filename, header=TRUE, sep=",")
data$ln_sal = log(data$salary)

data1 = data.frame(data$salary,data$ln_sal)
data2 = data[1:2,]
data3 = data[c(3,5),c(2,4)]

# data examination
head(data, 10)
tail(data,10)
dim(data)
str(data)
summary(data)
colnames(data)

table(data$black, exclude=NULL) # tabulate values
sum(is.na(data$salary)) # missings 
sapply(data, function(x) sum(is.na(x))) # missings

# OLS regression
a = lm(ln_sal~years+games+black, data=data)
summary(a)
coef(a)
y_hat = fitted(a)
res = residuals(a)
confint(a, level=.95)

Y = data$ln_sal
X = data[,3:5]

Y = as.matrix(Y)
X = as.matrix(X)

X = cbind(rep(1,length(Y)),X)

beta = solve(t(X)%*%X)%*%t(X)%*%Y
s_2 = (t(Y-X%*%beta)%*%(Y-X%*%beta))/(length(Y)-(ncol(X)))
s = sqrt(s_2)

windows()
par(mfrow = c(2, 2))
plot(a)

# 3. Testing
# individual significance
summary(a)
t = coef(summary(a))[2,1]/coef(summary(a))[2,2]
2*pt(t, 349, lower.tail=TRUE)
# single t-test
t_2 = (coef(summary(a))[2,1]-0.05)/coef(summary(a))[2,2]
2*pt(t_2, 349, lower.tail=TRUE)
# single linear restriction
# beta_years+beta_games = 3
numerator = coef(summary(a))[2,1]+coef(summary(a))[3,1]-3
denominator = sqrt(vcov(a)[2,2]+vcov(a)[3,3]+2*vcov(a)[2,3])
vcov(a) # variance-covariance matrix
t_3 = numerator/denominator
2*pt(t_3, 349, lower.tail=TRUE)
# overall significance
summary(a)
# joint significance (of a subset of parameters)
library(car)
linearHypothesis(a, c("years=0", "black=0"))
# set of linear restrictions
linearHypothesis(a, c("years=0", "black=games+3"))

# 4. Collinearity
# Dummy variable trap
data$nonblack = 1 - data$black
summary(lm(ln_sal~years+games+black+nonblack, data=data))

# pairwise correlations 
cor(data)

# VIF
vif(a)

# 5. Omitting relevant regressor
# true model
N = 200
X1 = rnorm(N,5,2)
X2 = X1+rnorm(N,3,1)
epsilon = rnorm(N,0,1)

Y_true = 2*X1+3*X2+epsilon

# OLS on true
true = lm(Y_true~X1+X2-1)
summary(true)

# OLS on omitted
omit = lm(Y_true~X1-1)
summary(omit)
  
# 6. Inclusion of irrelevant regressors
X3 = rnorm(N,4,3)

# OLS on extended
irr = lm(Y_true~X1+X2+X3-1)
summary(irr)

# 7. RESET test
library("lmtest")
resettest(a, power = 2:3)

data = cbind(data,y_hat)
data$fit2 = data$y_hat^2
data$fit3 = data$y_hat^3

ramsey = lm(ln_sal~years+games+black+fit2+fit3, data=data)
linearHypothesis(ramsey, c("fit2=0", "fit3=0"))

# 8. Heteroscedasticity
bptest(a)

gqtest(a)

bptest(a, ~ years*games +years*black +black*games + I(years^2)+ I(games^2), data = data)

library("skedastic")
white_lm(a, interactions = FALSE)

# 9. Autocorrelation
dwtest(a)
bgtest(a)

# 10. Normality
library("tseries")
jarque.bera.test(res)


