################################
# Econometrics SzD             #
# Topic 2: Endogeneity and IV  #
################################
rm(list=ls())

# 1. Consistency illustration
# generate a sequence of random numbers from normal distribution
n = 10 # sample size (increase)
x = rnorm(n,mean=5,sd=5)
mean(x) 

# 2. Convergence in distribution illustration
# generate many sequences of random numbers from normal distribution
x_standard = matrix(0, 1, 1000)

for (i in 1:1000) {
  x = rnorm(200,mean=5,sd=5)
  x_hat = mean(x)
  root_n = sqrt(200)
  x_standard[i] = (root_n*(x_hat-5))/5
}

hist(x_standard)
mean(x_standard)
sd(x_standard)

# 3. Measurement error - Exercise 2.2
x_true = seq(80,260,20)
x_obs = seq(0,0,length.out=10)
for (i in 1:5) {
  x_obs[i]=x_true[i]-20
}
for (i in 6:10) {
  x_obs[i]=x_true[i]+20
}
error = rnorm(10,0,1)
y_true = 25+0.6*x_true + error
measurement_error = rnorm(10,0,6)
y_obs = y_true + measurement_error

# regressions
summary(lm(y_true~x_true))
summary(lm(y_true~x_obs))
summary(lm(y_obs~x_true))
summary(lm(y_obs~x_obs))

# 4. IV example
filename <- "IV_example.csv"
data     <- read.csv(filename, header=TRUE, sep=",")

data$l_wage = log(data$wage)
data = data[is.finite(rowSums(data)),]

summary(data) # examine the data

# OLS regression
a = lm(l_wage~educ+exper+largecity+unemployment, data=data)
summary(a)

# What are the returns to schooling? 
  
# As we suspect that education might be endogenous, 
# we decide to go for IV estimation and 
# firstly we use only one instrument: the number of siblings.

# TSLS step-by-step
# 1st-stage in TSLS
b = lm(educ~exper+largecity+unemployment+siblings, data=data)
summary(b)

# Do you think (empirically) siblings is a good instrument?

educ_hat <- fitted(b)

# 2nd stage 
c = lm(l_wage~educ_hat+exper+largecity+unemployment, data=data)
summary(c) # IV estimates

# TSLS in one go
#install.packages("AER")
library("AER")

d = ivreg(l_wage~educ+exper+largecity+unemployment | exper+largecity+unemployment+siblings , data=data) 
summary(d)

# How large are the returns to schooling now? 
  
# Now, we use more instruments: 
# number of siblings, mother's education and father's education

e = ivreg(l_wage~educ+exper+largecity+unemployment | exper+largecity+unemployment+siblings+mothereduc+fathereduc , data=data) 
summary(e)

# How large are the returns to schooling now? 
# How more instruments affect the standard errors of IV estimators?
  
# TESTING
# exogeneity -- informal 
e$coefficients
d$coefficients

f = ivreg(l_wage~educ+exper+largecity+unemployment | exper+largecity+unemployment+fathereduc , data=data) 
f$coefficients # try different combinations

# Overidentifying Restrictions Test - for instrumental exogeneity
# H0: instruments are exogeneous
# compute residuals after model e
res = resid(e)
# regress the IV residuals on instruments and exogenous regressors
o_test = lm(res~exper+largecity+unemployment+siblings+mothereduc+fathereduc, data=data)
# test joint significance of instruments
linearHypothesis(o_test, c("siblings=0", "mothereduc=0", "fathereduc=0"))

# compute test-stat
test_stat = 3*0.1478

# critical values (chi-square: 2)
qchisq(0.05, 2, lower.tail=FALSE) # fail to reject H0

# alternatively
summary(e, diagnostics=TRUE)

# Instrumental relevance
# run 1st-stage
b = lm(educ~exper+largecity+unemployment+siblings, data=data)
summary(b)
# & look at F-stat for overall significance

# Hausman test for endogeneity
# H0: regressor is exogenous vs. H1: endogeneity
summary(e, diagnostics=TRUE)

